@@ -330,9 +330,9 @@ class KinovaGen3Arm(robot_arms.RobotArm):
         action = Base_pb2.Action()
 
         joint_offset = self.joint_positions[joint_id] if relative else 0
-        joint_angle = action.reach_joint_angles.joint_angles.joint_angles.add()
-        joint_angle.joint_identifier = joint_id
-        joint_angle.value = joint_offset + position
+        joints = self.joint_positions
+        joints[joint_id] = joint_offset + position
+        self.build_joint_angles_from_joints(action.reach_joint_angles.joint_angles, joints)
 
         if velocity is not None:
             action.reach_joint_angles.constraint.type = Base_pb2.JOINT_CONSTRAINT_SPEED
